Tool Tree Widget (tooltree)

# Tool Tree Widget (`tooltree`)

## Tool Tree

A ToolTree widget presenting the user with a set of actions organized in a tree structure.

class `orangecanvas.gui.tooltree.` `ToolTree`(parent=None, **kwargs)

  Bases: `PyQt5.QtWidgets.QWidget`

  A ListView like presentation of a list of actions.

  `triggered`(QAction)

    Signal emitted when an action in the widget is triggered.

  `hovered`(QAction)

    Signal emitted when an action in the widget is hovered.

  `setFlattened`(flatten)

    Show the actions in a flattened view.

  `flattened`()

    Are actions shown in a flattened tree (a list).

  `setRootIndex`(index)

    Set the root index

  `rootIndex`()

    Return the root index.

  `view`()

    Return the QTreeView instance used.

  `setActionRole`(role)

    Set the action role. By default this is UserRole

  `ensureCurrent`()

    Ensure the view has a current item if one is available.